/*****************************************************************************
 *                                                                           *
 * Module:       Altera_UP_Avalon_Video_In                                   *
 * Description:                                                              *
 *      This module processes a video input stream.                          *
 *                                                                           *
 * Modified by: Jordan Tymburski                                             *
 *  - removed all color and also modified the inside buffer.                 *
 *  - Implementing a grey scale version that just outputs an 8 bit           *
 *    grey scale version of rgb.                                             *
 *  - Pulled waitrequest, essentially its just streaming data now            *
 *  - Removed 50 MHz clock, changed from a dual clock to a single clock      *
 *  - Modified reset to become a default high reset                          *
 *  - Changing the deinterlacer: DONE
 *****************************************************************************/

module Video_In (
// Inputs
input				CLOCK_27,
input				reset_n,

input		[7:0]	TD_DATA,
input				TD_HS,
input				TD_VS,

// Outputs
output				TD_RESET,

output		[8:0] 	x,
output		[7:0] 	y,
output      [7:0]   pixel_data, /* 256 bit grey scale */
output				pixel_en
); 

/*****************************************************************************
 *                 Internal wires and registers Declarations                 *
 *****************************************************************************/

// Internal Wires
// Video In ITU-R 656 Decoder
wire		[7:0]	decoded_Y;
wire		[1:0]	decoded_pixel_info;
wire				decoded_valid_pixel;

// Video In Resize
wire		[7:0]	resize_pixel_data;
wire		[1:0]	resize_pixel_info;
wire				resize_pixel_en;

// Video In Deinterlacer
wire				deinterlacer_ready;
wire        [8:0]   x_tmp;
wire        [7:0]   y_tmp;

// Output Assignments
assign TD_RESET = 1'b1;
assign x = {x_tmp[8:1], ~x_tmp[0]}; /* Pixel flip */
assign y = y_tmp-14; /* Screen shift */

/*****************************************************************************
 *                              Internal Modules                             *
 *****************************************************************************/

itu_r_656_decoder itu_r_656_decoder (
	// Inputs
	.clk			(CLOCK_27),
	.reset_n		(reset_n),

	.TD_DATA		(TD_DATA),

	// Outputs
	.Y				(decoded_Y),
	
	.pixel_info		(decoded_pixel_info),
	.valid_pixel	(decoded_valid_pixel)
);

//video_in_buffer video_in_buffer (
//	// Inputs
//	.system_clk			(CLOCK_50),
//	.video_in_clk		(CLOCK_27),
//	.reset_n			(reset_n),
//
//	.Y_in				(decoded_Y),
//	.pixel_info_in		(decoded_pixel_info),
//	.valid_pixel		(decoded_valid_pixel),
//
//	.read_buffer		(read_buffer),
//
//	// Outputs
//	.buffer_has_data	(buffer_has_data),
//
//	.Y_out				(buffered_Y),
//	.pixel_info_out		(buffered_pixel_info)
//);

video_in_resize video_in_resize (
	// Inputs
	.clk			(CLOCK_27),
	.reset_n		(reset_n),

	.pixel_data_in	(decoded_Y),
	.pixel_info_in	(decoded_pixel_info),
	.pixel_en_in	(decoded_valid_pixel),

	// Outputs
	.pixel_data_out	(resize_pixel_data),
	.pixel_info_out	(resize_pixel_info),
	.pixel_en_out	(resize_pixel_en)
);

video_in_deinterlacer video_in_deinterlacer (
	// Inputs
	.clk						(CLOCK_27),
	.reset_n					(reset_n),

	.pixel_data					(resize_pixel_data),
	.pixel_info					(resize_pixel_info),
	.pixel_en					(resize_pixel_en),

	// Outputs
	.ready_for_data				(deinterlacer_ready),

	.address					({y_tmp,x_tmp}),
	.writedata					(pixel_data),
	.write						(pixel_en)
);

endmodule
